=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_, and this project adheres to `Semantic Versioning`_.

`Unreleased`_
-------------

`0.2.0`_ - 2021-12-24
---------------------

Added
^^^^^
* Added python310 support

Removed
^^^^^^^
* Dropped python36 support
* Removed the ability to include python files for settings

`0.1.1`_ - 2021-08-13
---------------------

Added
^^^^^
* Allow getting the value from a single setting

`0.1.0`_ - 2020-07-01
---------------------

Added
^^^^^
* Allow including python files for settings


.. _`unreleased`: https://github.com/spapanik/dj_settings/compare/v0.2.0...main
.. _`0.2.0`: https://github.com/spapanik/dj_settings/compare/v0.1.0...v0.2.0
.. _`0.1.1`: https://github.com/spapanik/dj_settings/compare/v0.1.0...v0.1.1
.. _`0.1.0`: https://github.com/spapanik/dj_settings/releases/tag/v0.1.0

.. _`Keep a Changelog`: https://keepachangelog.com/en/1.0.0/
.. _`Semantic Versioning`: https://semver.org/spec/v2.0.0.html
